# Security Policy

## Supported Versions

The following list shows the maintenance status of all versions. For each version,
the version of the corresponding core dependency (React Picture Annotation) is also
specified. We will try to make dash-picture-annotation always synchronized to the
version of React-Picture-Annotation.

| Version | Supported | Available on [PyPI :link:][link-pypi] | React-Picture-Annotation       |
| ------- | --------- | ------------------------------------- | ------------------------------ |
| `0.1.x` | :x:       | :white_check_mark:                    | [`1.2.0` :link:][link-rpa-120] |

## Reporting a Vulnerability

The vulnerability can be reported by submitting a [vulnerability issue :link:][link-issue].

Any reported vulnerability will be replied ASAP. Please follow the guidelines of the issue
template and let me know what to expect if the vulnerability is accepted or declined, etc.

Any vulnerability submitted for a not-supported version will be declined directly.

[link-pypi]:https://pypi.org/project/dash-picture-annotation
[link-issue]:https://github.com/cainmagi/dash-picture-annotation/security/advisories/new

[link-rpa-120]:https://github.com/Kunduin/react-picture-annotation/tree/v1.2.0
